summaryrefslogtreecommitdiff
path: root/libs/ardour/ardour/buffer_set.h
diff options
context:
space:
mode:
authorDavid Robillard <d@drobilla.net>2012-02-29 03:21:37 +0000
committerDavid Robillard <d@drobilla.net>2012-02-29 03:21:37 +0000
commit8de887f378b13e558bdd74e88be79dc96df9d7b4 (patch)
tree1942e36555c801bc0986e2796403719dc3e19331 /libs/ardour/ardour/buffer_set.h
parent9dd4d79d6c8cf3169b7f755883245597f919065e (diff)
Update to latest LV2 atom extension.
git-svn-id: svn://localhost/ardour2/branches/3.0@11548 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'libs/ardour/ardour/buffer_set.h')
-rw-r--r--libs/ardour/ardour/buffer_set.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/libs/ardour/ardour/buffer_set.h b/libs/ardour/ardour/buffer_set.h
index 5049eda70a..3cb6cbdbd9 100644
--- a/libs/ardour/ardour/buffer_set.h
+++ b/libs/ardour/ardour/buffer_set.h
@@ -112,13 +112,13 @@ public:
}
#ifdef LV2_SUPPORT
/** Get a MIDI buffer translated into an LV2 MIDI buffer for use with plugins.
* The index here corresponds directly to MIDI buffer numbers (i.e. the index
* passed to get_midi), translation back and forth will happen as needed.
* If atom_type is 0 the returned buffer will be in the old event API
* format. Otherwise, atom_type must be the URID for atom:Sequence.
*/
- LV2_Evbuf* get_lv2_midi(bool input, size_t i, uint32_t atom_type);
+ LV2_Evbuf* get_lv2_midi(bool input, size_t i, bool old_api);
/** Flush modified LV2 event output buffers back to Ardour buffers */
void flush_lv2_midi(bool input, size_t i);
@@ -112,13 +112,13 @@ public:
}
#ifdef LV2_SUPPORT
- /** Get a MIDI buffer translated into an LV2 MIDI buffer for use with plugins.
- * The index here corresponds directly to MIDI buffer numbers (i.e. the index
- * passed to get_midi), translation back and forth will happen as needed.
- * If atom_type is 0 the returned buffer will be in the old event API
- * format. Otherwise, atom_type must be the URID for atom:Sequence.
+ /** Get a MIDI buffer translated into an LV2 MIDI buffer for use with
+ * plugins. The index here corresponds directly to MIDI buffer numbers
+ * (i.e. the index passed to get_midi), translation back and forth will
+ * happen as needed. If old_api is true, the returned buffer will be in
+ * old event format. Otherwise it will be in new atom sequence format.
*/